colour.models.cie_lab Module — Colour 0.3.0 documentation

# colour.models.cie_lab Module

## CIE Lab Colourspace

Defines the CIE Lab colourspace transformations:

- `XYZ_to_Lab()`
- `Lab_to_XYZ()`
- `Lab_to_LCHab()`
- `LCHab_to_Lab()`

See also

CIE Lab Colourspace IPython Notebook

References

[1] | http://en.wikipedia.org/wiki/Lab_color_space (Last accessed 24 February 2014)

`colour.models.cie_lab.` `XYZ_to_Lab`(XYZ, illuminant=(0.34567, 0.3585))

  Converts from CIE XYZ colourspace to CIE Lab colourspace.

  Parameters: | XYZ (array_like, (3,)) – CIE XYZ colourspace matrix. illuminant (array_like, optional) – Reference illuminant chromaticity coordinates.
  Returns: | CIE Lab colourspace matrix.
  Return type: | ndarray, (3,)

  Notes

  - Input CIE XYZ is in domain [0, 1].
  - Input illuminant chromaticity coordinates are in domain [0, 1].
  - Output Lightness \(L^*\) is in domain [0, 100].

  References

  [2] | http://www.brucelindbloom.com/Eqn_XYZ_to_Lab.html (Last accessed 24 February 2014)

  Examples

      >>> XYZ_to_Lab(np.array([0.92193107, 1, 1.03744246]))
      array([ 100.        ,   -7.4178784...,  -15.8574210...])

`colour.models.cie_lab.` `Lab_to_XYZ`(Lab, illuminant=(0.34567, 0.3585))

  Converts from CIE Lab colourspace to CIE XYZ colourspace.

  Parameters: | Lab (array_like, (3,)) – CIE Lab colourspace matrix. illuminant (array_like, optional) – Reference illuminant chromaticity coordinates.
  Returns: | CIE XYZ colourspace matrix.
  Return type: | ndarray, (3,)

  Notes

  - Input Lightness \(L^*\) is in domain [0, 100].
  - Input illuminant chromaticity coordinates are in domain [0, 1].
  - Output CIE XYZ colourspace matrix is in domain [0, 1].

  References

  [3] | http://www.brucelindbloom.com/Eqn_Lab_to_XYZ.html (Last accessed 24 February 2014)

  Examples

      >>> Lab = np.array([100, -7.41787844, -15.85742105])
      >>> Lab_to_XYZ(Lab)
      array([ 0.9219310...,  1.        ,  1.0374424...])

`colour.models.cie_lab.` `Lab_to_LCHab`(Lab)

  Converts from CIE Lab colourspace to CIE LCHab colourspace.

  Parameters: | Lab (array_like, (3,)) – CIE Lab colourspace matrix.
  Returns: | CIE LCHab colourspace matrix.
  Return type: | ndarray, (3,)

  Notes

  - Lightness \(L^*\) is in domain [0, 100].

  References

  [4] | http://www.brucelindbloom.com/Eqn_Lab_to_LCH.html (Last accessed 24 February 2014)

  Examples

      >>> Lab = np.array([100, -7.41787844, -15.85742105])
      >>> Lab_to_LCHab(Lab)
      array([ 100.        ,   17.5066479...,  244.9304684...])

`colour.models.cie_lab.` `LCHab_to_Lab`(LCHab)

  Converts from CIE LCHab colourspace to CIE Lab colourspace.

  Parameters: | LCHab (array_like, (3,)) – CIE LCHab colourspace matrix.
  Returns: | CIE Lab colourspace matrix.
  Return type: | ndarray, (3,)

  Notes

  - Lightness \(L^*\) is in domain [0, 100].

  References

  [5] | http://www.brucelindbloom.com/Eqn_LCH_to_Lab.html (Last accessed 24 February 2014)

  Examples

      >>> LCHab = np.array([100, 17.50664796, 244.93046842])
      >>> LCHab_to_Lab(LCHab)
      array([ 100.        ,   -7.4178784...,  -15.8574210...])